==> haskell-project-template-0.2.0-5-armv7h.pkg.tar.xz: usr/share/haskell/haskell-project-template/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: project-template
version: 0.2.0
id: project-template-0.2.0-d6566e7240f3743e6a45d6e24c97e88d
key: proje_4ILKi0U2KK1I8rthVd4AwI
license: BSD3
maintainer: michael@fpcomplete.com
homepage: https://github.com/fpco/haskell-ide
synopsis: Specify Haskell project templates and generate files
description:
    See initial blog post for explanation: <http://www.yesodweb.com/blog/2012/09/project-templates>
category: Development
author: Michael Snoyman
exposed: True
exposed-modules:
    Text.ProjectTemplate
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/project-template-0.2.0
library-dirs: /usr/lib/ghc-7.10.3/site-local/project-template-0.2.0
data-dir: /usr/share/arm-linux-ghc-7.10.3/project-template-0.2.0
hs-libraries: HSproject-template-0.2.0-4ILKi0U2KK1I8rthVd4AwI
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    base64-bytestring-1.0.0.1-7819850819049320f81b6417431cc8a5
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    conduit-1.2.6.1-99a58e37479a2070047844a872c4445f
    conduit-extra-1.1.9.2-1bef4166ec3f53ae2e6d2e9011cd9cbe
    containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
    directory-1.2.2.0-17b2023f9d7e8036d19e6b52b4f75c98
    filepath-1.4.0.0-73e0bec80594160bf6dd6cb25217c6bf
    mtl-2.2.1-c516313407bc17046965067cb7cbb6a0
    resourcet-1.1.7-7e93b08fc7a9dc3281fd76904261e146
    text-1.2.1.3-6c3c87c392cdf2c29fca1c10bbf7250b
    transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
haddock-interfaces: /usr/share/doc/haskell-project-template/html/project-template.haddock
haddock-html: /usr/share/doc/haskell-project-template/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"

==> haskell-project-template-0.2.0-13-armv7h.pkg.tar.xz: usr/share/haskell/haskell-project-template/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: project-template
version: 0.2.0
id: project-template-0.2.0-cfd687309e52e13b0d0d1443c21dd612
key: proje_B1Jn23tOB3LCKEpGEzrZvK
license: BSD3
maintainer: michael@fpcomplete.com
homepage: https://github.com/fpco/haskell-ide
synopsis: Specify Haskell project templates and generate files
description:
    See initial blog post for explanation: <http://www.yesodweb.com/blog/2012/09/project-templates>
category: Development
author: Michael Snoyman
exposed: True
exposed-modules:
    Text.ProjectTemplate
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/project-template-0.2.0
library-dirs: /usr/lib/ghc-7.10.3/site-local/project-template-0.2.0
data-dir: /usr/share/arm-linux-ghc-7.10.3/project-template-0.2.0
hs-libraries: HSproject-template-0.2.0-B1Jn23tOB3LCKEpGEzrZvK
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    base64-bytestring-1.0.0.1-7819850819049320f81b6417431cc8a5
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    conduit-1.2.6.2-e9736ac2851958c9940f374454cdc4fe
    conduit-extra-1.1.10.1-e4383b2e14cc80179dd5007ca51887df
    containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
    directory-1.2.2.0-17b2023f9d7e8036d19e6b52b4f75c98
    filepath-1.4.0.0-73e0bec80594160bf6dd6cb25217c6bf
    mtl-2.2.1-c516313407bc17046965067cb7cbb6a0
    resourcet-1.1.7.2-b95e5d14f30eaa21587bc62eeb9aed0c
    text-1.2.2.0-2f82ea4adfdd656d9a8840ad2ee17cc0
    transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
haddock-interfaces: /usr/share/doc/haskell-project-template/html/project-template.haddock
haddock-html: /usr/share/doc/haskell-project-template/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
